@@ -111,22 +111,22 @@ class Caller(AbstractModel):
         :type ApplicationId: str
         :param OrganizationId: 主机构ID
         :type OrganizationId: str
-        :param SubOrganizationId: 下属机构ID
-        :type SubOrganizationId: str
         :param OperatorId: 经办人的用户ID
         :type OperatorId: str
+        :param SubOrganizationId: 下属机构ID
+        :type SubOrganizationId: str
         """
         self.ApplicationId = None
         self.OrganizationId = None
-        self.SubOrganizationId = None
         self.OperatorId = None
+        self.SubOrganizationId = None
 
 
     def _deserialize(self, params):
         self.ApplicationId = params.get("ApplicationId")
         self.OrganizationId = params.get("OrganizationId")
-        self.SubOrganizationId = params.get("SubOrganizationId")
         self.OperatorId = params.get("OperatorId")
+        self.SubOrganizationId = params.get("SubOrganizationId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -143,27 +143,27 @@ class CancelFlowRequest(AbstractModel):
 
     def __init__(self):
         r"""
+        :param FlowId: 签署流程id
+        :type FlowId: str
+        :param CancelMessage: 撤销原因，最长200个字符；
+        :type CancelMessage: str
         :param Operator: 操作用户id
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowId: 流程id
-        :type FlowId: str
-        :param CancelMessage: 撤销原因
-        :type CancelMessage: str
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         """
-        self.Operator = None
         self.FlowId = None
         self.CancelMessage = None
+        self.Operator = None
         self.Agent = None
 
 
     def _deserialize(self, params):
+        self.FlowId = params.get("FlowId")
+        self.CancelMessage = params.get("CancelMessage")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
-        self.FlowId = params.get("FlowId")
-        self.CancelMessage = params.get("CancelMessage")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
@@ -280,7 +280,7 @@ class Component(AbstractModel):
         :param ComponentType: 如果是 Component 控件类型，则可选类型为：
 TEXT - 内容文本控件
 DATE - 内容日期控件
-SELECT - 勾选框控件
+CHECK_BOX - 勾选框控件
 如果是 SignComponent 控件类型，则可选类型为：
 SIGN_SEAL - 签署印章控件
 SIGN_DATE - 签署日期控件
@@ -326,9 +326,9 @@ KEYWORD 关键字，使用ComponentId指定关键字
         :type GenerateMode: str
         :param ComponentDateFontSize: 日期控件类型字号
         :type ComponentDateFontSize: int
-        :param OffsetX: 指定关键字时横坐标偏移量
+        :param OffsetX: 指定关键字时横坐标偏移量，单位pt
         :type OffsetX: float
-        :param OffsetY: 指定关键字时纵坐标偏移量
+        :param OffsetY: 指定关键字时纵坐标偏移量，单位pt
         :type OffsetY: float
         """
         self.ComponentType = None
@@ -386,52 +386,52 @@ class CreateDocumentRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Operator: 无
-        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param FlowId: 签署流程编号,由CreateFlow接口返回
+        :type FlowId: str
         :param TemplateId: 用户上传的模板ID
         :type TemplateId: str
-        :param FlowId: 流程ID
-        :type FlowId: str
-        :param FileNames: 文件名列表
+        :param FileNames: 文件名列表,单个文件名最大长度200个字符
         :type FileNames: list of str
-        :param FormFields: 内容控件信息数组
-        :type FormFields: list of FormField
+        :param Operator: 无
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param ClientToken: 客户端Token，保持接口幂等性
-        :type ClientToken: str
+        :param FormFields: 内容控件信息数组
+        :type FormFields: list of FormField
         :param NeedPreview: 是否需要生成预览文件 默认不生成；
 预览链接有效期300秒；
         :type NeedPreview: bool
+        :param ClientToken: 客户端Token，保持接口幂等性,最大长度64个字符
+        :type ClientToken: str
         """
-        self.Operator = None
-        self.TemplateId = None
         self.FlowId = None
+        self.TemplateId = None
         self.FileNames = None
-        self.FormFields = None
+        self.Operator = None
         self.Agent = None
-        self.ClientToken = None
+        self.FormFields = None
         self.NeedPreview = None
+        self.ClientToken = None
 
 
     def _deserialize(self, params):
+        self.FlowId = params.get("FlowId")
+        self.TemplateId = params.get("TemplateId")
+        self.FileNames = params.get("FileNames")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
-        self.TemplateId = params.get("TemplateId")
-        self.FlowId = params.get("FlowId")
-        self.FileNames = params.get("FileNames")
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
         if params.get("FormFields") is not None:
             self.FormFields = []
             for item in params.get("FormFields"):
                 obj = FormField()
                 obj._deserialize(item)
                 self.FormFields.append(obj)
-        if params.get("Agent") is not None:
-            self.Agent = Agent()
-            self.Agent._deserialize(params.get("Agent"))
-        self.ClientToken = params.get("ClientToken")
         self.NeedPreview = params.get("NeedPreview")
+        self.ClientToken = params.get("ClientToken")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -448,9 +448,9 @@ class CreateDocumentResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DocumentId: 返回的电子文档ID
+        :param DocumentId: 签署流程电子文档ID
         :type DocumentId: str
-        :param PreviewFileUrl: 返回合同文件的预览地址 5分钟内有效。仅当NeedPreview为true 时返回
+        :param PreviewFileUrl: 签署流程文件的预览地址, 5分钟内有效。仅当NeedPreview为true 时返回
 注意：此字段可能返回 null，表示取不到有效值。
         :type PreviewFileUrl: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -474,67 +474,70 @@ class CreateFlowByFilesRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Operator: 调用方用户信息
-        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowName: 流程名称
+        :param FlowName: 签署流程名称,最大长度200个字符
         :type FlowName: str
-        :param FileIds: 签署pdf文件的资源编号列表
-        :type FileIds: list of str
         :param Approvers: 签署参与者信息
         :type Approvers: list of ApproverInfo
-        :param FlowDescription: 流程描述
-        :type FlowDescription: str
-        :param Unordered: 发送类型：
-true：无序签
-false：有序签
-注：默认为false（有序签）
-        :type Unordered: bool
-        :param FlowType: 流程的类型
-        :type FlowType: str
-        :param Deadline: 流程的签署截止时间
-        :type Deadline: int
+        :param FileIds: 签署pdf文件的资源编号列表，通过UploadFiles接口获取
+        :type FileIds: list of str
+        :param Operator: 调用方用户信息
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param Agent: 应用号信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         :param Components: 经办人内容控件配置。可选类型为：
 TEXT - 内容文本控件
 MULTI_LINE_TEXT - 多行文本控件
+CHECK_BOX - 勾选框控件
 注：默认字体大小为 字号12
         :type Components: list of Component
-        :param CcInfos: 被抄送人的信息列表
-        :type CcInfos: list of CcInfo
-        :param NeedPreview: 是否需要预览，true：预览模式，false：非预览（默认）
+        :param Deadline: 签署流程的签署截止时间。
+值为unix时间戳,精确到秒,不传默认为当前时间一年后
+        :type Deadline: int
+        :param Unordered: 发送类型：
+true：无序签
+false：有序签
+注：默认为false（有序签）
+        :type Unordered: bool
+        :param NeedPreview: 是否需要预览，true：预览模式，false：非预览（默认）；
+预览链接有效期300秒；
         :type NeedPreview: bool
+        :param FlowDescription: 签署流程描述,最大长度1000个字符
+        :type FlowDescription: str
+        :param FlowType: 签署流程的类型(如销售合同/入职合同等)，最大长度200个字符
+        :type FlowType: str
+        :param CcInfos: 被抄送人的信息列表。
+注:此功能为白名单功能，若有需要，请联系电子签客服开白使用
+        :type CcInfos: list of CcInfo
+        :param CustomShowMap: 合同显示的页卡模板，说明：只支持{合同名称}, {发起方企业}, {发起方姓名}, {签署方N企业}, {签署方N姓名}，且N不能超过签署人的数量，N从1开始
+        :type CustomShowMap: str
         """
-        self.Operator = None
         self.FlowName = None
-        self.FileIds = None
         self.Approvers = None
-        self.FlowDescription = None
-        self.Unordered = None
-        self.FlowType = None
-        self.Deadline = None
+        self.FileIds = None
+        self.Operator = None
         self.Agent = None
         self.Components = None
-        self.CcInfos = None
+        self.Deadline = None
+        self.Unordered = None
         self.NeedPreview = None
+        self.FlowDescription = None
+        self.FlowType = None
+        self.CcInfos = None
+        self.CustomShowMap = None
 
 
     def _deserialize(self, params):
-        if params.get("Operator") is not None:
-            self.Operator = UserInfo()
-            self.Operator._deserialize(params.get("Operator"))
         self.FlowName = params.get("FlowName")
-        self.FileIds = params.get("FileIds")
         if params.get("Approvers") is not None:
             self.Approvers = []
             for item in params.get("Approvers"):
                 obj = ApproverInfo()
                 obj._deserialize(item)
                 self.Approvers.append(obj)
-        self.FlowDescription = params.get("FlowDescription")
-        self.Unordered = params.get("Unordered")
-        self.FlowType = params.get("FlowType")
-        self.Deadline = params.get("Deadline")
+        self.FileIds = params.get("FileIds")
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
@@ -544,13 +547,18 @@ MULTI_LINE_TEXT - 多行文本控件
                 obj = Component()
                 obj._deserialize(item)
                 self.Components.append(obj)
+        self.Deadline = params.get("Deadline")
+        self.Unordered = params.get("Unordered")
+        self.NeedPreview = params.get("NeedPreview")
+        self.FlowDescription = params.get("FlowDescription")
+        self.FlowType = params.get("FlowType")
         if params.get("CcInfos") is not None:
             self.CcInfos = []
             for item in params.get("CcInfos"):
                 obj = CcInfo()
                 obj._deserialize(item)
                 self.CcInfos.append(obj)
-        self.NeedPreview = params.get("NeedPreview")
+        self.CustomShowMap = params.get("CustomShowMap")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -567,7 +575,7 @@ class CreateFlowByFilesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param FlowId: 流程编号
+        :param FlowId: 签署流程编号
         :type FlowId: str
         :param PreviewUrl: 合同预览链接
 注意：此字段可能返回 null，表示取不到有效值。
@@ -593,46 +601,50 @@ class CreateFlowRequest(AbstractModel):
 
     def __init__(self):
         r"""
+        :param FlowName: 签署流程名称,最大长度200个字符
+        :type FlowName: str
+        :param Approvers: 签署流程参与者信息
+        :type Approvers: list of FlowCreateApprover
         :param Operator: 操作人信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowName: 流程的名字, 长度不能超过200，中文字母数字下划线
-        :type FlowName: str
-        :param Approvers: 参与者信息
-        :type Approvers: list of FlowCreateApprover
-        :param FlowDescription: 流程的描述, 长度不能超过1000
-        :type FlowDescription: str
-        :param Unordered: 发送类型(true为无序签,false为顺序签)
-        :type Unordered: bool
-        :param FlowType: 流程的种类(如销售合同/入职合同等)
-        :type FlowType: str
-        :param DeadLine: 过期时间戳,如果是0则为不过期
-        :type DeadLine: int
-        :param CallbackUrl: 执行结果的回调URL(需要以http://或者https://)开头
-        :type CallbackUrl: str
-        :param UserData: 用户自定义字段(需进行base64 encode),回调的时候会进行透传, 长度需要小于20480
-        :type UserData: str
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param ClientToken: 客户端Token，保持接口幂等性
+        :param Unordered: 发送类型(true为无序签,false为顺序签)
+        :type Unordered: bool
+        :param DeadLine: 签署流程的签署截止时间。
+值为unix时间戳,精确到秒,不传默认为当前时间一年后
+        :type DeadLine: int
+        :param FlowType: 签署流程的类型(如销售合同/入职合同等)，最大长度200个字符
+        :type FlowType: str
+        :param UserData: 用户自定义字段(需进行base64 encode),回调的时候会进行透传, 长度需要小于20480
+        :type UserData: str
+        :param FlowDescription: 签署流程描述,最大长度1000个字符
+        :type FlowDescription: str
+        :param ClientToken: 客户端Token，保持接口幂等性,最大长度64个字符
         :type ClientToken: str
+        :param CustomShowMap: 合同显示的页卡模板，说明：只支持{合同名称}, {发起方企业}, {发起方姓名}, {签署方N企业}, {签署方N姓名}，且N不能超过签署人的数量，N从1开始
+        :type CustomShowMap: str
+        :param RelatedFlowId: 暂未开放
+        :type RelatedFlowId: str
+        :param CallbackUrl: 暂未开放
+        :type CallbackUrl: str
         """
-        self.Operator = None
         self.FlowName = None
         self.Approvers = None
-        self.FlowDescription = None
-        self.Unordered = None
-        self.FlowType = None
-        self.DeadLine = None
-        self.CallbackUrl = None
-        self.UserData = None
+        self.Operator = None
         self.Agent = None
+        self.Unordered = None
+        self.DeadLine = None
+        self.FlowType = None
+        self.UserData = None
+        self.FlowDescription = None
         self.ClientToken = None
+        self.CustomShowMap = None
+        self.RelatedFlowId = None
+        self.CallbackUrl = None
 
 
     def _deserialize(self, params):
-        if params.get("Operator") is not None:
-            self.Operator = UserInfo()
-            self.Operator._deserialize(params.get("Operator"))
         self.FlowName = params.get("FlowName")
         if params.get("Approvers") is not None:
             self.Approvers = []
@@ -640,16 +652,21 @@ class CreateFlowRequest(AbstractModel):
                 obj = FlowCreateApprover()
                 obj._deserialize(item)
                 self.Approvers.append(obj)
-        self.FlowDescription = params.get("FlowDescription")
-        self.Unordered = params.get("Unordered")
-        self.FlowType = params.get("FlowType")
-        self.DeadLine = params.get("DeadLine")
-        self.CallbackUrl = params.get("CallbackUrl")
-        self.UserData = params.get("UserData")
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        self.Unordered = params.get("Unordered")
+        self.DeadLine = params.get("DeadLine")
+        self.FlowType = params.get("FlowType")
+        self.UserData = params.get("UserData")
+        self.FlowDescription = params.get("FlowDescription")
         self.ClientToken = params.get("ClientToken")
+        self.CustomShowMap = params.get("CustomShowMap")
+        self.RelatedFlowId = params.get("RelatedFlowId")
+        self.CallbackUrl = params.get("CallbackUrl")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -666,7 +683,7 @@ class CreateFlowResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param FlowId: 流程编号
+        :param FlowId: 签署流程编号
         :type FlowId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -687,46 +704,49 @@ class CreateMultiFlowSignQRCodeRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param TemplateId: 模版ID
+        :param TemplateId: 模板ID
         :type TemplateId: str
+        :param FlowName: 签署流程名称，最大长度不超过200字符
+        :type FlowName: str
         :param Operator: 用户信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowName: 合同名称
-        :type FlowName: str
         :param Agent: 应用信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param FlowEffectiveDay: 合同有效天数 默认7天 最高设置不超过30天
+        :param CallbackUrl: 回调地址,最大长度1000字符串
+回调时机：
+用户通过签署二维码发起签署流程时，企业额度不足导致失败
+        :type CallbackUrl: str
+        :param MaxFlowNum: 最大可发起签署流程份数，默认5份 
+发起流程数量超过此上限后二维码自动失效
+        :type MaxFlowNum: int
+        :param FlowEffectiveDay: 签署流程有效天数 默认7天 最高设置不超过30天
         :type FlowEffectiveDay: int
         :param QrEffectiveDay: 二维码有效天数 默认7天 最高设置不超过90天
         :type QrEffectiveDay: int
-        :param MaxFlowNum: 最大合同份数，默认5份 超过此上限 二维码自动失效
-        :type MaxFlowNum: int
-        :param CallbackUrl: 回调地址
-        :type CallbackUrl: str
         """
         self.TemplateId = None
-        self.Operator = None
         self.FlowName = None
+        self.Operator = None
         self.Agent = None
+        self.CallbackUrl = None
+        self.MaxFlowNum = None
         self.FlowEffectiveDay = None
         self.QrEffectiveDay = None
-        self.MaxFlowNum = None
-        self.CallbackUrl = None
 
 
     def _deserialize(self, params):
         self.TemplateId = params.get("TemplateId")
+        self.FlowName = params.get("FlowName")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
-        self.FlowName = params.get("FlowName")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        self.CallbackUrl = params.get("CallbackUrl")
+        self.MaxFlowNum = params.get("MaxFlowNum")
         self.FlowEffectiveDay = params.get("FlowEffectiveDay")
         self.QrEffectiveDay = params.get("QrEffectiveDay")
-        self.MaxFlowNum = params.get("MaxFlowNum")
-        self.CallbackUrl = params.get("CallbackUrl")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -768,34 +788,34 @@ class CreateSchemeUrlRequest(AbstractModel):
         r"""
         :param Operator: 调用方用户信息，参考通用结构
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param Agent: 调用方渠道信息，参考通用结构
+        :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param Name: 姓名
-        :type Name: str
-        :param Mobile: 手机号
-        :type Mobile: str
-        :param PathType: 跳转页面 1: 小程序合同详情 2: 小程序合同列表页 0: 不传, 默认主页
-        :type PathType: int
-        :param FlowId: 合同详情 id (PathType=1时必传)
-        :type FlowId: str
-        :param OrganizationName: 企业名称
-        :type OrganizationName: str
         :param EndPoint: 链接类型
 HTTP：跳转电子签小程序的http_url，
 APP：第三方APP或小程序跳转电子签小程序的path。
 默认为HTTP类型
         :type EndPoint: str
+        :param Name: 姓名,最大长度50个字符
+        :type Name: str
+        :param Mobile: 手机号，大陆手机号11位
+        :type Mobile: str
+        :param OrganizationName: 企业名称
+        :type OrganizationName: str
+        :param FlowId: 签署流程编号 (PathType=1时必传)
+        :type FlowId: str
+        :param PathType: 跳转页面 1: 小程序合同详情 2: 小程序合同列表页 0: 不传, 默认主页
+        :type PathType: int
         :param AutoJumpBack: 是否自动回跳 true：是， false：否。该参数只针对"APP" 类型的签署链接有效
         :type AutoJumpBack: bool
         """
         self.Operator = None
         self.Agent = None
+        self.EndPoint = None
         self.Name = None
         self.Mobile = None
-        self.PathType = None
-        self.FlowId = None
         self.OrganizationName = None
-        self.EndPoint = None
+        self.FlowId = None
+        self.PathType = None
         self.AutoJumpBack = None
 
 
@@ -806,12 +826,12 @@ APP：第三方APP或小程序跳转电子签小程序的path。
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        self.EndPoint = params.get("EndPoint")
         self.Name = params.get("Name")
         self.Mobile = params.get("Mobile")
-        self.PathType = params.get("PathType")
-        self.FlowId = params.get("FlowId")
         self.OrganizationName = params.get("OrganizationName")
-        self.EndPoint = params.get("EndPoint")
+        self.FlowId = params.get("FlowId")
+        self.PathType = params.get("PathType")
         self.AutoJumpBack = params.get("AutoJumpBack")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
@@ -856,56 +876,57 @@ class DescribeFileUrlsRequest(AbstractModel):
 - 印章  “SEAL”
 - 流程 "FLOW"
         :type BusinessType: str
+        :param BusinessIds: 业务编号的数组，如模板编号、文档编号、印章编号
+最大支持20个资源
+        :type BusinessIds: list of str
         :param Operator: 操作者信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param BusinessIds: 业务编号的数组，如模板编号、文档编号、印章编号
-        :type BusinessIds: list of str
-        :param FileType: 文件类型，"JPG", "PDF","ZIP"等
-        :type FileType: str
+        :param Agent: 应用相关信息
+        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         :param FileName: 下载后的文件命名，只有fileType为zip的时候生效
         :type FileName: str
-        :param Offset: 指定资源起始偏移量
+        :param FileType: 文件类型，"JPG", "PDF","ZIP"等
+        :type FileType: str
+        :param Offset: 指定资源起始偏移量，默认0
         :type Offset: int
         :param Limit: 指定资源数量，查询全部资源则传入-1
         :type Limit: int
-        :param Agent: 应用相关信息
-        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param UrlTtl: 下载url过期时间，0: 按默认值5分钟，允许范围：1s~24*60*60s(1天)
+        :param UrlTtl: 下载url过期时间，单位秒。0: 按默认值5分钟，允许范围：1s~24*60*60s(1天)
         :type UrlTtl: int
-        :param CcToken: 流程校验发送邮件权限
-        :type CcToken: str
-        :param Scene: 场景
+        :param Scene: 暂不开放
         :type Scene: str
+        :param CcToken: 暂不开放
+        :type CcToken: str
         """
         self.BusinessType = None
-        self.Operator = None
         self.BusinessIds = None
-        self.FileType = None
+        self.Operator = None
+        self.Agent = None
         self.FileName = None
+        self.FileType = None
         self.Offset = None
         self.Limit = None
-        self.Agent = None
         self.UrlTtl = None
-        self.CcToken = None
         self.Scene = None
+        self.CcToken = None
 
 
     def _deserialize(self, params):
         self.BusinessType = params.get("BusinessType")
+        self.BusinessIds = params.get("BusinessIds")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
-        self.BusinessIds = params.get("BusinessIds")
-        self.FileType = params.get("FileType")
-        self.FileName = params.get("FileName")
-        self.Offset = params.get("Offset")
-        self.Limit = params.get("Limit")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        self.FileName = params.get("FileName")
+        self.FileType = params.get("FileType")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
         self.UrlTtl = params.get("UrlTtl")
-        self.CcToken = params.get("CcToken")
         self.Scene = params.get("Scene")
+        self.CcToken = params.get("CcToken")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -952,23 +973,23 @@ class DescribeFlowBriefsRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Operator: 操作人信息
-        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param FlowIds: 需要查询的流程ID列表
         :type FlowIds: list of str
-        :param Agent: 代理商信息
+        :param Operator: 操作人信息
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         """
-        self.Operator = None
         self.FlowIds = None
+        self.Operator = None
         self.Agent = None
 
 
     def _deserialize(self, params):
+        self.FlowIds = params.get("FlowIds")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
-        self.FlowIds = params.get("FlowIds")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
@@ -1101,7 +1122,7 @@ class DescribeThirdPartyAuthCodeRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param AuthCode: AuthCode 值
+        :param AuthCode: 电子签小程序跳转客户小程序时携带的授权查看码
         :type AuthCode: str
         """
         self.AuthCode = None
@@ -1305,62 +1326,60 @@ class FlowCreateApprover(AbstractModel):
         :type ApproverType: int
         :param OrganizationName: 如果签署方为企业，需要填入企业全称
         :type OrganizationName: str
-        :param Required: 是否需要签署
-- `false`: 不需要签署
--  `true`:  需要签署
-        :type Required: bool
         :param ApproverName: 签署方经办人姓名
         :type ApproverName: str
         :param ApproverMobile: 签署方经办人手机号码
         :type ApproverMobile: str
-        :param ApproverIdCardNumber: 签署方经办人证件号码
-        :type ApproverIdCardNumber: str
         :param ApproverIdCardType: 签署方经办人证件类型ID_CARD 身份证
 HONGKONG_AND_MACAO 港澳居民来往内地通行证
 HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         :type ApproverIdCardType: str
+        :param ApproverIdCardNumber: 签署方经办人证件号码
+        :type ApproverIdCardNumber: str
         :param RecipientId: 签署方经办人在模板中的角色ID
         :type RecipientId: str
-        :param UserId: 签署方经办人的用户ID,和签署方经办人姓名+手机号+证件必须有一个
-        :type UserId: str
+        :param VerifyChannel: 签署意愿确认渠道,WEIXINAPP:人脸识别
+        :type VerifyChannel: list of str
+        :param NotifyType: 是否发送短信，sms--短信通知，none--不通知，默认为sms
+        :type NotifyType: str
         :param IsFullText: 签署前置条件：是否需要阅读全文，默认为不需要
         :type IsFullText: bool
         :param PreReadTime: 签署前置条件：阅读时长限制，默认为不需要
         :type PreReadTime: int
-        :param NotifyType: 是否发送短信，sms--短信通知，none--不通知，默认为sms
-        :type NotifyType: str
-        :param VerifyChannel: 签署意愿确认渠道,WEIXINAPP:人脸识别
-        :type VerifyChannel: list of str
+        :param UserId: 签署方经办人的用户ID,和签署方经办人姓名+手机号+证件必须有一个
+        :type UserId: str
+        :param Required: 当前只支持true，默认为true
+        :type Required: bool
         """
         self.ApproverType = None
         self.OrganizationName = None
-        self.Required = None
         self.ApproverName = None
         self.ApproverMobile = None
-        self.ApproverIdCardNumber = None
         self.ApproverIdCardType = None
+        self.ApproverIdCardNumber = None
         self.RecipientId = None
-        self.UserId = None
+        self.VerifyChannel = None
+        self.NotifyType = None
         self.IsFullText = None
         self.PreReadTime = None
-        self.NotifyType = None
-        self.VerifyChannel = None
+        self.UserId = None
+        self.Required = None
 
 
     def _deserialize(self, params):
         self.ApproverType = params.get("ApproverType")
         self.OrganizationName = params.get("OrganizationName")
-        self.Required = params.get("Required")
         self.ApproverName = params.get("ApproverName")
         self.ApproverMobile = params.get("ApproverMobile")
-        self.ApproverIdCardNumber = params.get("ApproverIdCardNumber")
         self.ApproverIdCardType = params.get("ApproverIdCardType")
+        self.ApproverIdCardNumber = params.get("ApproverIdCardNumber")
         self.RecipientId = params.get("RecipientId")
-        self.UserId = params.get("UserId")
+        self.VerifyChannel = params.get("VerifyChannel")
+        self.NotifyType = params.get("NotifyType")
         self.IsFullText = params.get("IsFullText")
         self.PreReadTime = params.get("PreReadTime")
-        self.NotifyType = params.get("NotifyType")
-        self.VerifyChannel = params.get("VerifyChannel")
+        self.UserId = params.get("UserId")
+        self.Required = params.get("Required")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1381,7 +1400,7 @@ class FormField(AbstractModel):
         :type ComponentValue: str
         :param ComponentId: 控件id
         :type ComponentId: str
-        :param ComponentName: 控件名字
+        :param ComponentName: 控件名字，最大长度不超过30字符
         :type ComponentName: str
         """
         self.ComponentValue = None
@@ -1513,26 +1532,26 @@ class StartFlowRequest(AbstractModel):
 
     def __init__(self):
         r"""
+        :param FlowId: 签署流程编号，由CreateFlow接口返回
+        :type FlowId: str
         :param Operator: 用户信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowId: 流程编号
-        :type FlowId: str
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
-        :param ClientToken: 客户端Token，保持接口幂等性
+        :param ClientToken: 客户端Token，保持接口幂等性,最大长度64个字符
         :type ClientToken: str
         """
-        self.Operator = None
         self.FlowId = None
+        self.Operator = None
         self.Agent = None
         self.ClientToken = None
 
 
     def _deserialize(self, params):
+        self.FlowId = params.get("FlowId")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
-        self.FlowId = params.get("FlowId")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
@@ -1674,7 +1693,7 @@ class UploadFile(AbstractModel):
         r"""
         :param FileBody: Base64编码后的文件内容
         :type FileBody: str
-        :param FileName: 文件名
+        :param FileName: 文件名，最大长度不超过200字符
         :type FileName: str
         """
         self.FileBody = None
